"""Este es el modulo "nester.py", suministra una funcion llamada
print_lol() la cual imprime listas que pueden incluir o no otras listas
anidadas"""
def print_lol(la_lista, indent=False, nivel=0):
    """Esta función lleva un argumento posicional llamado "la_lista", que es
    cualquier lista en python (o posiblemente listas enlazadas). Cada item
    de datos de la lista suministrada se imprime (recursivamente) en la pantalla
    en su propia linea.
    Un segundo argumento llamado "nivel" se utiliza para insertar tab-stops
    cuando se haya encontrado una lista anidada"""
    for cada_item in la_lista:
        if isinstance(cada_item, list):
            print_lol(cada_item, indent, nivel+1)
        else:
            if indent:
                for tab_stop in range(nivel):
                    print("\t",end='')
            print(cada_item)
            
